#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.16
visibility:           public
id:                   gitit-0.16-9EJdqIvvvULAWetNCGwTsO
key:                  gitit-0.16-9EJdqIvvvULAWetNCGwTsO
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  7753bb27dbffe6b69c3d0e264dbeb6f4
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Server Network.Gitit.State Network.Gitit.Types
    Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.16-9EJdqIvvvULAWetNCGwTsO
depends:
    HStringTemplate-0.8.8-4oA7F5kQlHw6QL1ZsME60R
    HTTP-4000.5.0-CfJfpXMvMr6LUUoIZynQQ5
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT base-4.18.2.1
    base64-bytestring-1.2.1.0-KV8aVMC7eDp4VhaST1z1XE
    blaze-html-0.9.2.0-3zJbEruN1MK4AfSPvaGc85 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-3dHxz3aqr811vmzHtrSnm5
    feed-1.3.2.1-7nTGTthK7Sbw04w7OliAc filepath-1.4.300.1
    filestore-0.6.5.1-8zZusvjyfae5vMM8YA8OjV ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-J0e0N8AF0mCD9IWWNQls42
    hoauth2-2.14.0-BjumOciVVgLH885tb1julh
    hslogger-1.3.2.0-J16AmHi76RmEIcf2UoXdPr
    http-client-tls-0.3.6.4-5gkLBXAH8K17sWQOnZNh1
    http-conduit-2.3.9.1-Gizy51sy45GDHHtdH3WJ9H
    json-0.11-8lNNdGLbGjvAsWhsz0sm7l mtl-2.3.1
    network-3.1.4.0-6Vir8NKcwTtGDZOkjzNXEQ
    network-bsd-2.8.1.0-CYNQaa879cvHnuSe8LGwhd
    network-uri-2.6.4.2-9CHKirNVw9rJ9Z87o3gbmr
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.1.0-IjaM3n4DA9HK2PHWNCOcpr
    pandoc-3.6-7az35xKa2Dl42Q86KtaBZy
    pandoc-types-1.23.1.1-1kTADMTWRxHJWJCN3qbIpT parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-8RkfyIpOhzwIqsi8QOPf6g
    recaptcha-0.1.0.4-GJEvWsLOnwHHWr7nQxWPKx
    safe-0.3.21-Ki9XWKg9cP9KpwzlIW2n9t
    skylighting-0.14.5-DZByfCiNBwzAe4NM1DVKkf
    split-0.2.5-2swF3b7SyGG9a7yRckeoD1 syb-0.7.3-IWvKvWWONKwAx7053zcTAl
    tagsoup-0.14.8-K4W49sUXtt63HRkBY8fHh
    temporary-1.3-HgSGYx8rMrE1HkWShJwAxb text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-IM4LIQ7HMAeGvckdhvfW0a
    url-2.1.3-7Kl4E3eXP9D927NfHGnLmQ
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    uuid-1.3.16.1-L1O8TurgJfVK0OVoZ8lrSO xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-G0eRvIJ0IW7EoHoyGSnQye
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-94kOfjVrJYN1ppoOSC7EiN
    zlib-0.7.1.0-5Rjzs1QvYLu4tPh1e1fSOv

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

